@@ -1,26 +1,5 @@
 gads_get_report_helper <- function(
-  resource              = 'campaign',
-  fields                = c('campaign.id',
-                            'campaign.name',
-                            'customer.id',
-                            'customer.descriptive_name',
-                            'campaign.status',
-                            'segments.date',
-                            'metrics.all_conversions',
-                            'metrics.clicks',
-                            'metrics.cost_micros',
-                            'metrics.ctr',
-                            'metrics.impressions',
-                            'metrics.interaction_rate',
-                            'metrics.interactions',
-                            'metrics.invalid_clicks'),
-  where                 = NULL,
-  order_by              = NULL,
-  limit                 = NULL,
-  parameters            = NULL,
-  date_from             = Sys.Date() - 15,
-  date_to               = Sys.Date() - 1,
-  during                = c(NA, "TODAY", "YESTERDAY", "LAST_7_DAYS", "LAST_BUSINESS_WEEK", "THIS_MONTH", "LAST_MONTH", "LAST_14_DAYS", "LAST_30_DAYS", "THIS_WEEK_SUN_TODAY", "THIS_WEEK_MON_TODAY", "LAST_WEEK_SUN_SAT", "LAST_WEEK_MON_SUN"),
+  gaql_query,
   customer_id           = getOption('gads.customer.id'),
   login_customer_id     = getOption('gads.login.customer.id'),
   include_resource_name = FALSE,
@@ -35,9 +14,6 @@ gads_get_report_helper <- function(
   # manager_customer id
   login_customer_id <- ifelse(length(login_customer_id) == 0, customer_id, login_customer_id)
 
-  # check args
-  during <- match.arg(during)
-
   # check login and custimer ids
   if ( is.null(customer_id) ) {
     gads_abort('customer_id is require argument, please set it and retry your request.')
@@ -49,50 +25,10 @@ gads_get_report_helper <- function(
   # info
   if (verbose) cli_alert_info('Compose query')
 
-  # --------------
-  # compose query
-  # select block
-  fields <- gsub("[\\s\\n\\t]", "",  fields, perl = TRUE) %>%
-            tolower() %>%
-            str_c(collapse = ', ')
-
-  if ( any(is.null(date_from), is.null(date_to)) & is.null(where) ) {
-    where_clause <- ""
-  } else if ( !is.na(during) ) {
-    where <- str_c(where, collapse = " AND ")
-    where_clause <- str_glue("WHERE segments.date DURING {during} AND {where}")
-  } else if ( any(is.null(date_from), is.null(date_to)) ) {
-    where <- str_c(where, collapse = " AND ")
-    where_clause <- str_glue("WHERE {where}")
-  } else {
-    sd <- format(as.Date(date_from), '%Y-%m-%d')
-    fd <- format(as.Date(date_to), '%Y-%m-%d')
-    where_clause <- ifelse( is.null(where), str_glue("WHERE segments.date BETWEEN '{sd}' AND '{fd}'"), str_glue("WHERE segments.date BETWEEN '{sd}' AND '{fd}' AND {where}") )
-  }
-
-  # params block
-  params_clause <- ifelse( is.null(parameters), '', str_glue('PARAMETERS {parameters}') )
-
-  # order by block
-  order_by_clause <- ifelse( is.null(order_by), '', str_glue('ORDER BY {str_c(order_by, collapse=", ")}'))
-
-  # limit block
-  limit_clause <- ifelse( is.null(limit), '', str_glue('LIMIT {limit}') )
-
   # --------------
   # build GAQL Query
-  body <- list(query =
-                 str_glue('
-       SELECT {fields}
-
-       FROM {resource}
-
-       {where_clause}
-
-       {order_by_clause}
-       {limit_clause}
-       {params_clause}')) %>%
-    toJSON(auto_unbox = T, pretty = T)
+  body <- list(query = gaql_query) %>%
+          toJSON(auto_unbox = T, pretty = T)
 
   # --------------
   # info
